Package: personalr
Title: Automated Personal Package Setup
Version: 1.0.3
Authors@R: 
    person("Sebastian", "Carl", , "mrcaseb@gmail.com", role = c("aut", "cre"))
Description: Functions to setup a personal R package that attaches given
    libraries and exports personal helper functions.
License: MIT + file LICENSE
URL: https://mrcaseb.github.io/personalr/index.html,
        https://github.com/mrcaseb/personalr
BugReports: https://github.com/mrcaseb/personalr/issues
Imports: desc, devtools, fs, glue, magrittr, purrr, rprojroot,
        rstudioapi, usethis, utils, withr, xfun
Suggests: dplyr, tibble
Encoding: UTF-8
RoxygenNote: 7.2.1
NeedsCompilation: no
Packaged: 2022-08-11 21:42:08 UTC; S.Carl
Author: Sebastian Carl [aut, cre]
Maintainer: Sebastian Carl <mrcaseb@gmail.com>
Repository: CRAN
Date/Publication: 2022-08-11 22:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 13:15:02 UTC; unix
